@@ -10,7 +10,7 @@
 ################################
 
 alfapcr.tune <- function(y, x, M = 10, maxk = 50, a = seq(-1, 1, by = 0.1),
-  mat = NULL, ncores = 1, graph = TRUE, col.nu = 15) {
+                         mat = NULL, ncores = 1, graph = TRUE, col.nu = 15) {
   ## oiko can be either "normal", "binomial" or "poisson"
   ## depending on the type of the independent variable
   ## "normal" is set by default
@@ -41,78 +41,31 @@ alfapcr.tune <- function(y, x, M = 10, maxk = 50, a = seq(-1, 1, by = 0.1),
   } else oiko <- "normal"
 
   if (oiko == 'normal') {
-
-    if ( ncores <=1 ) {
-      tic <- proc.time()
-      for ( i in 1:da ) {
-        z <- alfa(x, a[i])$aff
-        mod <- pcr.tune(y, z, M = M, maxk = maxk, mat = mat,
-        ncores = 1, graph = FALSE)
-        mspe2[, , i] <- mod$msp
-      }
-      toc <- proc.time() - tic
-
-    } else {
-
-      tac <- proc.time()
-      ## dimensions of the matrix val a warning message should appear
-      ## but with options(warn = -1) you will not see it
-      cl <- makePSOCKcluster(ncores)
-      registerDoParallel(cl)
-      ms <- numeric( M * maxk)
-      ww <- foreach(i = 1:da, .combine = cbind, .export = c("pcr.tune",
-         "alfa", "helm") ) %dopar% {
-        z <- alfa(x, a[i])$aff
-        mod <- pcr.tune(y, z, M = M, maxk = maxk, mat = mat, ncores = 1, graph = FALSE)
-        ms[i] <- as.vector(mod$msp)
-      }
-      for (i in 1:da) {
-        mspe2[, , i] <- matrix(ww[, i], nrow = M)
-      }
-      runtime <- proc.time() - tac
-
+    tic <- proc.time()
+    for ( i in 1:da ) {
+      z <- alfa(x, a[i])$aff
+      mod <- pcr.tune(y, z, M = M, maxk = maxk, mat = mat,
+                      ncores = ncores, graph = FALSE)
+      mspe2[, , i] <- mod$msp
     }
+    toc <- proc.time() - tic
 
   } else {
-
-    if (ncores <= 1) {
-      tac <- proc.time()
-
-      for ( i in 1:da ) {
-        z <- alfa(x, a[i])$aff
-        mod <- glmpcr.tune(y, z, M = M, maxk = maxk,
-        mat = mat, ncores = ncores, graph = FALSE)
-        mspe2[, , i] <- mod$msp
-      }
-      runtime <- proc.time() - tac
-
-    } else {
-      tac <- proc.time()
-      ## dimensions of the matrix val a warning message should appear
-      ## but with options(warn = -1) you will not see it
-      cl <- makePSOCKcluster(ncores)
-      registerDoParallel(cl)
-      ms <- numeric( M * maxk)
-      ww <- foreach(i = 1:da, .combine = cbind, .export = c("glmpcr.tune",
-         "alfa", "helm") ) %dopar% {
-        z <- alfa(x, a[i])$aff
-        mod <- glmpcr.tune(y, z, M = M, maxk = maxk, mat = mat, ncores = 1, graph = FALSE)
-        ms[i] <- as.vector(mod$msp)
-                                                            }
-      for (i in 1:da) {
-        mspe2[, , i] <- matrix(ww[, i], nrow = M)
-      }
-      runtime <- proc.time() - tac
-
+    tic <- proc.time()
+    for ( i in 1:da ) {
+      z <- alfa(x, a[i])$aff
+      mod <- glmpcr.tune(y, z, M = M, maxk = maxk,
+                         mat = mat, ncores = ncores, graph = FALSE)
+      mspe2[, , i] <- mod$msp
     }
-
+    toc <- proc.time() - tic
   }
 
   dimnames(mspe2) <- list(folds = 1:M, PC = paste("PC", 1:d, sep = ""), a = a)
   mspe <- array( dim = c(da, d, M) )
   for (i in 1:M)  mspe[, , i] <- t( mspe2[i, , 1:da] )
   dimnames(mspe) <- list(a = a, PC = paste("PC", 1:d, sep = ""), folds = 1:M )
-  mean.mspe <- apply(mspe, 1:2, mean)
+  mean.mspe <- t( colMeans( aperm(mspe) ) )   ## apply(mspe, 1:2, mean)
   best.par <- ( which(mean.mspe == min(mean.mspe), arr.ind = TRUE)[1, ] )
   opt.mspe <- mean.mspe[ best.par[1], best.par[2] ]
   estb <- mspe[ best.par[1], best.par[2], 1:M ] - apply(mspe, 3, min)
@@ -120,8 +73,8 @@ alfapcr.tune <- function(y, x, M = 10, maxk = 50, a = seq(-1, 1, by = 0.1),
   rownames(mean.mspe) = a   ;  colnames(mspe) = paste("PC", 1:d, sep = "")
 
   if (graph == TRUE) {
-    filled.contour(a, 1:d, mean.mspe, xlab = expression( paste(alpha, " values") ), 
-    ylab = "Number of PCs")
+    filled.contour(a, 1:d, mean.mspe, xlab = expression( paste(alpha, " values") ),
+                   ylab = "Number of PCs")
   }
 
   best.par <- c( a[ best.par[1] ], best.par[2] )
@@ -130,4 +83,3 @@ alfapcr.tune <- function(y, x, M = 10, maxk = 50, a = seq(-1, 1, by = 0.1),
   names(performance) <- c("bias corrected mspe", "estimated bias")
   list(mspe = mean.mspe, best.par = best.par, performance = performance, runtime = toc)
 }
-
