@@ -23,15 +23,16 @@ el.test2 <- function(y1, y2, R = 0, ncores = 1, graph = FALSE) {
   d <- ncol(y1)  ## number of variables
   n1 <- nrow(y1)   ;   n2 <- nrow(y2)  ## sample sizes
   n <- n1 + n2  ## total sample size
-  s1 <- ( (n1 - 1) / n1 ) * cov(y1)  ;  s2 <- ( (n2 - 1) / n2 ) * cov(y2)
-  m1 <- colMeans(y1)    ;    m2 <- colMeans(y2)  ## mean vectors
+  s1 <- ( (n1 - 1) / n1 ) * cov(y1)   ;   s2 <- ( (n2 - 1) / n2 ) * cov(y2)
+  m1 <- as.vector( Rfast::colmeans(y1) )
+  m2 <- as.vector( Rfast::colmeans(y2) )  ## mean vectors
   ## mu is the estimate of the common mean vector
   v1 <- solve(s1)    ;   v2 <- solve(s2)
   a1 <- n1 * v1    ;    a2 <-  n2 * v2
-  mu1 <- solve( a1 + a2, a1 %*% m1 + a2 %*% m2 )
+  muc <- solve( a1 + a2, a1 %*% m1 + a2 %*% m2 )
 
   runtime <- proc.time()
-  apot <- nlm( elpa, mu1 )
+  apot <- nlm( elpa, muc )
   test <- apot$minimum
   mu <- apot$estimate
   runtime <- proc.time() - runtime
@@ -60,10 +61,10 @@ el.test2 <- function(y1, y2, R = 0, ncores = 1, graph = FALSE) {
 
     ## else bootstrap calibration is implemented
   } else if (R > 2) {
-    ybar1 <- colMeans(y1)
-    ybar2 <- colMeans(y2)
-    z1 <- y1 - rep( ybar1 - mu1, rep(n1, d) )
-    z2 <- y2 - rep( ybar2 - mu1, rep(n2, d) )
+    ybar1 <- as.vector( Rfast::colmeans(y1) )
+    ybar2 <- as.vector( Rfast::colmeans(y2) )
+    z1 <- y1 - rep( ybar1 - muc, rep(n1, d) )
+    z2 <- y2 - rep( ybar2 - muc, rep(n2, d) )
 
     if (ncores == 1) {
       runtime <- proc.time()
@@ -72,7 +73,7 @@ el.test2 <- function(y1, y2, R = 0, ncores = 1, graph = FALSE) {
         b1 <- sample(1:n1, n1, replace = TRUE)
         b2 <- sample(1:n2, n2, replace = TRUE)
         y1 <- z1[b1, ]    ;    y2 <- z2[b2, ]
-        apot <- nlm( elpa, mu1 )
+        apot <- nlm( elpa, muc )
         tb[i] <- apot$minimum
       }
       runtime <- proc.time() - runtime
@@ -87,7 +88,7 @@ el.test2 <- function(y1, y2, R = 0, ncores = 1, graph = FALSE) {
             b1 <- sample(1:n1, n1, replace = TRUE)
             b2 <- sample(1:n2, n2, replace = TRUE)
             y1 <- z1[b1, ]    ;    y2 <- z2[b2, ]
-            apot <- nlm( elpa, mu1 )
+            apot <- nlm( elpa, muc )
             tb[i] <- apot$minimum
       }
 
