@@ -30,8 +30,8 @@ james <- function(y1, y2, a = 0.05, R = 999, graph = FALSE) {
   p <- ncol(y1)  ## dimensionality of the data
   n1 <- nrow(y1)  ;  n2 <- nrow(y2)  ## sample sizes
   n <- n1 + n2  ## the total sample size
-  ybar1 <- colMeans(y1)  ## sample mean vector of the first sample
-  ybar2 <- colMeans(y2)  ## sample mean vector of the second sample
+  ybar1 <- as.vector( Rfast::colmeans(y1) ) ## sample mean vector of the first sample
+  ybar2 <- as.vector( Rfast::colmeans(y2) )  ## sample mean vector of the second sample
   dbar <- ybar2 - ybar1  ## difference of the two mean vectors
   mesoi <- rbind(ybar1, ybar2)
   rownames(mesoi) <- c("Sample 1", "Sample 2")
@@ -39,10 +39,10 @@ james <- function(y1, y2, a = 0.05, R = 999, graph = FALSE) {
   if ( is.null(colnames(y1)) ) {
     colnames(mesoi) <- paste("X", 1:p, sep = "")
   } else  colnames(mesoi) <- colnames(y1)
-  A1 <- Rfast::cova(y1)/n1
-  A2 <- Rfast::cova(y2)/n2
+  A1 <- cov(y1)/n1
+  A2 <- cov(y2)/n2
   V <- A1 + A2  ## covariance matrix of the difference
-  Vinv <- solve(V)
+  Vinv <- chol2inv( chol(V) )   ## same as solve(V), but faster
   test <- sum( dbar %*% Vinv * dbar )
   b1 <- Vinv %*% A1
   b2 <- Vinv %*% A2
@@ -53,7 +53,7 @@ james <- function(y1, y2, a = 0.05, R = 999, graph = FALSE) {
     ## James test
     A <- 1 + (1/(2 * p)) * ( trb1^2/(n1 - 1) + trb2^2/(n2 - 1) )
     B <- ( 1/(p * (p + 2)) ) * ( sum(b1 * b1) / (n1 - 1) +
-                                   sum(b2 * b2)/(n2 - 1) + 0.5 * trb1 ^ 2/ (n1 - 1) + 0.5 * trb2^2/(n2 - 1) )
+         sum(b2 * b2)/(n2 - 1) + 0.5 * trb1 ^ 2/ (n1 - 1) + 0.5 * trb2^2/(n2 - 1) )
     x2 <- qchisq(1 - a, p)
     delta <- (A + B * x2)
     twoha <- x2 * delta  ## corrected critical value of the chi-square
@@ -79,8 +79,8 @@ james <- function(y1, y2, a = 0.05, R = 999, graph = FALSE) {
   } else  if (R > 2) {
     ## bootstrap calibration
     runtime <- proc.time()
-    a1inv <- solve(A1)
-    a2inv <- solve(A2)
+    a1inv <- chol2inv( chol(A1) )
+    a2inv <- chol2inv( chol(A2) )
     mc <- solve( a1inv + a2inv ) %*% ( a1inv %*% ybar1 + a2inv %*% ybar2 )
     ## mc is the combined sample mean vector
     ## the next two rows bring the mean vectors of the two sample equal
@@ -95,7 +95,7 @@ james <- function(y1, y2, a = 0.05, R = 999, graph = FALSE) {
       b1 <- sample(1:n1, n1, replace = TRUE)
       b2 <- sample(1:n2, n2, replace = TRUE)
       xb1 <- x1[b1, ]     ;      xb2 <- x2[b2, ]
-      db <- colMeans(xb1) - colMeans(xb2)  ## difference of the two mean vectors
+      db <- as.vector( Rfast::colmeans(xb1) ) - as.vector( Rfast::colmeans(xb2) )  ## difference of the two mean vectors
       Vb <- cov(xb1) / n1 + cov(xb2) / n2  ## covariance matrix of the difference
       tb[i] <- sum( db %*% solve(Vb, db ) )
     }
