@@ -27,8 +27,8 @@ ridge.reg <- function(y, x, lambda, B = 1, xnew = NULL) {
   p <- ncol(x)  ## dimensionality of x
   my <- sum(y) / n
   yy <- y - my   ## center the dependent variables
-  mx <- colMeans(x)
-  s <- Rfast::colVars(x, std = TRUE)
+  mx <- as.vector( Rfast::colmeans(x) )
+  s <- as.vector( Rfast::colVars(x, std = TRUE) )
   xx <- ( t(x) - mx )/s  ## standardize the independent variables
   xx <- t(xx)
 
@@ -49,7 +49,7 @@ ridge.reg <- function(y, x, lambda, B = 1, xnew = NULL) {
       yb <- yy[id, ]     ;     xb <- xx[id, ]
       be[i, ] <- solve( crossprod(xb) + lamip, crossprod(xb, yb) )
     }
-    seb <- matrix( Rfast::colVars(be,std = TRUE), nrow = p ) ## bootstrap standard errors of betas
+    seb <- matrix( as.vector( Rfast::colVars(be, std = TRUE) ), nrow = p ) ## bootstrap standard errors of betas
   }
 
   ## seb contains the standard errors of the coefficients
